// ignore_for_file: depend_on_referenced_packages

import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter_svg/svg.dart';
import 'package:flutter_widget_from_html_core/flutter_widget_from_html_core.dart';
import 'package:phoenix_widgets/phoenix_widgets.dart';

class PhoenixExpandableListPage extends StatefulWidget {
  const PhoenixExpandableListPage({Key? key}) : super(key: key);

  @override
  State<PhoenixExpandableListPage> createState() =>
      _PhoenixExpandableContentBlockPageState();
}

class _PhoenixExpandableContentBlockPageState
    extends State<PhoenixExpandableListPage> {
  List<ExpendableData> expendableData = [];
  late ExampleExpandableData expandableData;

  @override
  void initState() {
    super.initState();
    getExampleExpandableData().then(
      (result) {
        expandableData = result;
        for (int i = 0; i < result.items!.length; i++) {
          expendableData.add(
            ExpendableData(
              title: Text(result.items![i].question!),
              content: HtmlWidget(result.items![i].answer!),
            ),
          );
        }
        setState(() {});
      },
    );
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(
        title: const Text('Phoenix Expandable Content Sample'),
      ),
      body: SingleChildScrollView(
        child: Column(
          children: [
            for (int i = 0; i < expendableData.length; i++)
              PhoenixExpandableList(
                expendableData: expendableData[i],
                margin: const EdgeInsets.symmetric(horizontal: 16, vertical: 8),
                padding: const EdgeInsets.all(16),
                expandColor: Colors.white,
                shrinkColor: const Color(0xffF9F9F9),
                radius: 5,
                shrinkImage: SvgPicture.asset("assets/ic_minus.svg"),
                expandImage: SvgPicture.asset("assets/ic_plus.svg"),
                showData: expendableData[i].show,
                callback: () {
                  setState(() {
                    expendableData[i].show = !expendableData[i].show;
                  });
                },
              )
          ],
        ),
      ),
    );
  }

  Future<ExampleExpandableData> getExampleExpandableData() async {
    return ExampleExpandableData.fromJson(jsonDecode(
        await DefaultAssetBundle.of(context)
            .loadString("assets/json/example_expandable_data.json")));
  }
}

class ExampleExpandableData {
  List<Items>? items;

  ExampleExpandableData({this.items});

  ExampleExpandableData.fromJson(Map<String, dynamic> json) {
    if (json['items'] != null) {
      items = <Items>[];
      json['items'].forEach((v) {
        items!.add(Items.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    if (items != null) {
      data['items'] = items!.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class Items {
  String? question;
  String? answer;

  Items({this.question, this.answer});

  Items.fromJson(Map<String, dynamic> json) {
    question = json['question'];
    answer = json['answer'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['question'] = question;
    data['answer'] = answer;
    return data;
  }
}
