import 'package:flutter/material.dart';
import 'package:flutter_svg/svg.dart';

// ignore: must_be_immutable
class PhoenixCheckbox extends StatelessWidget {
  PhoenixCheckbox({
    Key? key,
    required this.onChange,
    this.checkedIcon,
    this.uncheckedIcon,
    this.isChecked = false,
  }) : super(key: key);

  final Function(bool) onChange;
  final Widget? checkedIcon, uncheckedIcon;
  bool isChecked;

  bool get value => isChecked;

  set value(bool? newValue) {
    isChecked = newValue ?? false;
  }

  @override
  Widget build(BuildContext context) {
    final firstChild = checkedIcon ??
        SvgPicture.asset(
          'assets/images/ic_check.svg',
          package: 'phoenix_widgets',
        );

    final secondChild = uncheckedIcon ??
        SvgPicture.asset(
          'assets/images/ic_uncheck.svg',
          package: 'phoenix_widgets',
        );

    final crossFadeState =
        value ? CrossFadeState.showFirst : CrossFadeState.showSecond;

    return InkWell(
      onTap: () {
        value = !value;
        onChange(value);
      },
      child: AnimatedCrossFade(
        firstChild: firstChild,
        secondChild: secondChild,
        crossFadeState: crossFadeState,
        duration: const Duration(milliseconds: 100),
      ),
    );
  }
}
