import 'package:flutter/material.dart';

class PhoenixChip extends StatelessWidget {
  const PhoenixChip({
    Key? key,
    required this.title,
    required this.items,
    required this.callback,
    this.backgroundChipColor,
    this.lineChipWidth,
    this.outlineChipColor,
    this.chipTextPadding,
    this.chipPadding,
    this.chipSpacing,
    this.chipTextStyle,
  }) : super(key: key);

  final Widget title;
  final Color? backgroundChipColor;
  final double? lineChipWidth;
  final Color? outlineChipColor;
  final EdgeInsets? chipTextPadding;
  final EdgeInsets? chipPadding;
  final double? chipSpacing;
  final Function(int index) callback;
  final List<String> items;
  final TextStyle? chipTextStyle;

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        title,
        Padding(
          padding: chipPadding ??
              const EdgeInsets.symmetric(horizontal: 16, vertical: 8),
          child: Wrap(
            spacing: chipSpacing ?? 8,
            children: [
              for (int i = 0; i < items.length; i++) ...[
                ActionChip(
                  label: Text(
                    items[i],
                    style: chipTextStyle,
                  ),
                  shape: StadiumBorder(
                    side: BorderSide(
                      color: outlineChipColor ?? Colors.grey,
                      width: lineChipWidth ?? 1,
                    ),
                  ),
                  backgroundColor: backgroundChipColor ?? Colors.white,
                  padding: chipTextPadding ??
                      const EdgeInsets.symmetric(vertical: 4, horizontal: 16),
                  onPressed: (){
                    callback(i);
                  },
                )
              ]
            ],
          ),
        ),
      ],
    );
  }
}
